@@ -1,7 +1,17 @@
 # -*- coding: utf-8 -*-
 #
 # Picard, the next-generation MusicBrainz tagger
-# Copyright (C) 2007 Lukáš Lalinský
+#
+# Copyright (C) 2007-2008 Lukáš Lalinský
+# Copyright (C) 2008 Will
+# Copyright (C) 2009, 2019-2020 Philipp Wolfer
+# Copyright (C) 2011, 2013 Michael Wiencek
+# Copyright (C) 2013, 2019 Wieland Hoffmann
+# Copyright (C) 2013-2014, 2018 Laurent Monin
+# Copyright (C) 2016 Rahul Raturi
+# Copyright (C) 2016-2018 Sambhav Kothari
+# Copyright (C) 2017 Antonio Larrosa
+# Copyright (C) 2018 Bob Swift
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,6 +27,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
+
 from functools import partial
 import locale
 import os.path
@@ -142,7 +153,7 @@ class InterfaceOptionsPage(OptionsPage):
         self.ui = Ui_InterfaceOptionsPage()
         self.ui.setupUi(self)
         self.ui.ui_language.addItem(_('System default'), '')
-        language_list = [(l[0], l[1], _(l[2])) for l in UI_LANGUAGES]
+        language_list = [(lang[0], lang[1], _(lang[2])) for lang in UI_LANGUAGES]
 
         def fcmp(x):
             return locale.strxfrm(x[2])
